@@ -539,6 +539,8 @@ GtkWidget *create_shapemenu(MainView * main)
  */
 static void create_toolbar(MainView * main)
 {
+        GtkToolItem * ti;
+        
 	/*
 	 * Create new GTK toolbar 
 	 */
@@ -671,6 +673,18 @@ static void create_toolbar(MainView * main)
 	gtk_toolbar_insert(GTK_TOOLBAR(main->toolbar), main->redo_tb, -1);
 	g_signal_connect(G_OBJECT(main->redo_tb), "clicked", G_CALLBACK(callback_redo), main);
 
+        /* Search entry widget */
+	gtk_toolbar_insert(GTK_TOOLBAR(main->toolbar), gtk_separator_tool_item_new(), -1);
+        ti = gtk_tool_item_new();
+        gtk_tool_item_set_expand(ti, TRUE);
+        main->search_entry = gtk_entry_new();
+        g_signal_connect(G_OBJECT(main->search_entry), "activate", G_CALLBACK(callback_search_activate), main);
+        gtk_container_add(GTK_CONTAINER(ti), main->search_entry);
+        gtk_toolbar_insert(main->toolbar, ti, -1);
+        ti = gtk_tool_button_new(gtk_image_new_from_icon_name("qgn_addr_icon_search_service", GTK_ICON_SIZE_SMALL_TOOLBAR), _("Search"));
+        g_signal_connect(G_OBJECT(ti), "clicked", G_CALLBACK(callback_search_activate), main);
+        gtk_toolbar_insert(main->toolbar, ti, -1);
+
 	/*
 	 * Connect signals to buttons 
 	 */
@@ -757,6 +771,7 @@ void create_textarea(MainView * main)
  */
 void create_treeview(MainView * main)
 {
+        main->color_highlight = "#ffff00";
 	main->scrolledtree = gtk_scrolled_window_new(NULL, NULL);
 /*#ifdef MAEMOPADPLUS_FINGER_FRIENDLY
         hildon_helper_set_thumb_scrollbar(main->scrolledtree, TRUE);
@@ -764,8 +779,7 @@ void create_treeview(MainView * main)
 	gtk_widget_show(main->scrolledtree);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(main->scrolledtree), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	GtkTreeStore *tstore = gtk_tree_store_new(N_COLUMNS, G_TYPE_STRING, GDK_TYPE_PIXBUF,
-																						G_TYPE_POINTER);
+	GtkTreeStore *tstore = gtk_tree_store_new(N_COLUMNS, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_POINTER, G_TYPE_STRING);
 
 	main->treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(tstore));
 	g_object_unref(G_OBJECT(tstore));
@@ -778,6 +792,7 @@ void create_treeview(MainView * main)
 	gtk_tree_view_column_pack_start(column, renderer2, FALSE);
 	gtk_tree_view_column_pack_start(column, renderer1, FALSE);
 
+	gtk_tree_view_column_add_attribute(column, renderer1, "cell-background", NODE_BGCOLOR);
 	gtk_tree_view_column_add_attribute(column, renderer1, "text", NODE_NAME);
 	gtk_tree_view_column_add_attribute(column, renderer2, "pixbuf", NODE_PIXBUF);
 
@@ -806,6 +821,7 @@ void create_treeview(MainView * main)
 	gtk_tree_view_expand_all(GTK_TREE_VIEW(main->treeview));
 	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(main->treeview), TRUE);
 	gtk_tree_view_set_fixed_height_mode(GTK_TREE_VIEW(main->treeview), FALSE);
+	gtk_tree_view_set_enable_tree_lines(GTK_TREE_VIEW(main->treeview), TRUE);
 
 	g_signal_connect(G_OBJECT(select), "changed", G_CALLBACK(callback_treeview_change), main);
 #ifndef EXPANDING_ROWS
